# ASIMOV Universe for Python

[![License](https://img.shields.io/badge/license-Public%20Domain-blue.svg)](https://unlicense.org)
[![Compatibility](https://img.shields.io/badge/python-3.13%2B-blue)](https://endoflife.date/python)
[![Package](https://img.shields.io/pypi/v/asimov-universe)](https://pypi.org/project/asimov-universe/)

🚧 _We are building in public. This is presently under heavy construction._

## 🛠️ Prerequisites

- [Python](https://python.org) 3.13+

## ⬇️ Installation

### Installation via PyPI

```bash
pip install asimov-universe --pre
```

## 👨‍💻 Development

```bash
git clone https://github.com/asimov-platform/asimov-universe.py.git
```

- - -

[![Share on X](https://img.shields.io/badge/share%20on-x-03A9F4?logo=x)](https://x.com/intent/post?url=https://github.com/asimov-platform/asimov-universe.py&text=ASIMOV%20Universe%20for%20Python)
[![Share on Reddit](https://img.shields.io/badge/share%20on-reddit-red?logo=reddit)](https://reddit.com/submit?url=https://github.com/asimov-platform/asimov-universe.py&title=ASIMOV%20Universe%20for%20Python)
[![Share on Hacker News](https://img.shields.io/badge/share%20on-hn-orange?logo=ycombinator)](https://news.ycombinator.com/submitlink?u=https://github.com/asimov-platform/asimov-universe.py&t=ASIMOV%20Universe%20for%20Python)
[![Share on Facebook](https://img.shields.io/badge/share%20on-fb-1976D2?logo=facebook)](https://www.facebook.com/sharer/sharer.php?u=https://github.com/asimov-platform/asimov-universe.py)
[![Share on LinkedIn](https://img.shields.io/badge/share%20on-linkedin-3949AB?logo=linkedin)](https://www.linkedin.com/sharing/share-offsite/?url=https://github.com/asimov-platform/asimov-universe.py)
